(* $Id: rpm.ml,v 1.3 2005/11/01 01:31:23 martin Exp $
 *
 * rpm.ml: the Rpm package for ocaml
 *
 * Copyright (C) 2005  Martin Biely
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)

(* uses Rpmtag *)
type fd
type header
type header_iter
type lead
type db
type db_iter

type hMagic = | HEADER_MAGIC_NO 
	      | HEADER_MAGIC_YES

type tag = Rpmtag.t
type header_value = | Null | Char of char | Int of int | Int32 of int32 
		    | String of string | StringArray of string array  
	          (*| Bin of string |Int64 of int64  *)	(* these two are not implemented *)
type header_entry = tag*header_value

external _set_error_callback: string->unit = "ml_error_set_callback"

let set_error_callback (cb:int->string->unit) = 
  begin
    Callback.register "rpmerror" cb;
    _set_error_callback "rpmerror";
    ()
  end

external from_fd: Unix.file_descr->fd = "ml_fdDup"
external openfile: string->string->fd option = "ml_Fopen"

  (** Fclose is called automagically through finalization **)
  (**external closefile: fd->unit = "ml_Fclose" **)
  (** For compatibility: **)
let closefile fd = ()
external lead_read: fd->lead = "ml__readLead"
external header_read: fd->hMagic->header option = "ml_headerRead"
(* external header_write: fd->header->unit = "ml_headerWrite" *)
external header_init_iterator: header->header_iter = "ml_headerInitIterator"
external header_next_iterator: header_iter->header_entry option = "ml__headerNextIterator"
external header_get_entry: header->tag->header_entry option = "ml__headerGetEntry"
external db_open: string->db option = "ml__rpmdbOpen"
external db_init_iterator: db->tag->string->db_iter option = "ml__rpmdbInitIterator"
external db_next_iterator: db_iter->header option = "ml__rpmdbNextIterator"
external read_config: unit->unit = "ml__rpmReadConfigFiles"
external rpmvercmp: string->string->int = "ml_rpmvercmp"
external increace_verbosity: unit->unit = "ml__rpmIncreaseVerbosity"

external foobar: unit->db option = "ml_foobar"

let string_of_header_value = function
  | Null -> "(null)"
  | Char c -> Printf.sprintf "Char(%c)" c
  | Int i  -> Printf.sprintf "Int(%d)" i
  | Int32 i  -> Printf.sprintf "Int32(%s)" (Int32.to_string i)
  | String s -> Printf.sprintf "String(%s)" s
  | StringArray sa -> 
      let b = Buffer.create (10*(Array.length sa)) in
      let s = Array.length sa in
      for i = 0 to (s-2) do
	Buffer.add_string b sa.(i);
	Buffer.add_string b ", "
      done;
      Buffer.add_string b sa.(s-1);
      Printf.sprintf "StringArray(%s)" (Buffer.contents b)
      

(*let _ = set_error_callback (fun c s -> ())*)

let _ = read_config ()
