(* $Id: apttest.ml,v 1.2 2005/10/31 20:36:24 martin Exp $
 *
 * apttest - just reads some information from apt pkglist files
 *           as can be found in /var/state/apt/lists/
 *
 * Copyright (C) 2005  Martin Biely
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)

let rpmerror code string = 
  Printf.fprintf stderr "TEST-ERROR: %d -> %s\n" code string
;;

let _ = Rpm.set_error_callback rpmerror in

let fd = match Rpm.openfile Sys.argv.(1) "r" with Some x -> x | _ -> failwith("openfile") in

let show_unknown_headers hdr = 
  let rec loop iter = 
    let x = Rpm.header_next_iterator iter in
    match x with 
    | None -> ()
    | Some((Rpmtag.UNKNOWN(x)),y) -> 
	Printf.printf "found unknown: %d value=%s\n" x (Rpm.string_of_header_value y);
	loop iter
    | _ -> loop iter
  in
  let iter = Rpm.header_init_iterator hdr in
  loop iter
in
let rec hdr_loop i = 
  match Rpm.header_read fd Rpm.HEADER_MAGIC_YES with
  | Some(hdr) -> (
      (
	if i = 0 then show_unknown_headers hdr ;
	match Rpm.header_get_entry hdr Rpmtag.NAME with
	| Some(_,Rpm.String(name)) ->  Printf.printf "[%d] name: %s\n" i name
	| None -> Printf.fprintf stderr "name %d couldn't be retrieved\n" i
	| _ -> Printf.fprintf stderr "name %d is not a string\n" i
      );
      flush stderr; flush stdout;
      hdr_loop (i+1))
  | _ -> ()
in
hdr_loop 0;

Printf.printf "done\n"

