(* $Id $
 *
 * installtest - rpm -hiv <one packagefile>
 *
 * Copyright (C) 2005  Martin Biely
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)

let _ = Rpm.read_config ()

let rpmerror code string = 
  Printf.fprintf stderr "TEST-ERROR: %d -> %s\n" code string
;;

let usage () = 
  begin
    Printf.printf "Error: no arg; run as\n";
    Printf.printf "\t./installtest [-i] pkgfile to install or\n";
    Printf.printf "\t./installtest -e pkgname to erase\n";
    Printf.printf "\t./installtest -u pkgfile to upgrade\n";
    exit(0)
  end
in

let some_or_fail str = function 
  | Some(x) -> x
  | _ -> failwith (Printf.sprintf "%s is not some!" str)
in

let some_string_or_fail str = function
  | Some(x,Rpm.String(y)) -> y
  | _ -> failwith (Printf.sprintf "%s is not some(,string)!" str)
in

let _ = Rpm.set_error_callback rpmerror in
let _ = Rpminstall.init () in

let arguments = some_or_fail "arguments" (Rpminstall.arguments_create ()) in
let _ = Rpminstall.arguments_set_install_flags arguments
  [Rpminstall.INSTALL_LABEL;Rpminstall.INSTALL_HASH] in

begin
  let argc =  Array.length Sys.argv in
  if argc < 2 then
    usage ()
  else
    match argc,Sys.argv.(1) with
    | 2,pkgfile -> ignore(Rpminstall.do_install arguments [|pkgfile|])
    | 3,"-i"    -> ignore(Rpminstall.do_install arguments [|Sys.argv.(2)|])
    | 3,"-e"    -> ignore(Rpminstall.do_erase   arguments [|Sys.argv.(2)|])
    | 3,"-u"    -> 
	let _ = Rpminstall.arguments_set_install_flags arguments
	  [Rpminstall.INSTALL_LABEL;Rpminstall.INSTALL_HASH;Rpminstall.INSTALL_UPGRADE] in
	ignore(Rpminstall.do_install   arguments [|Sys.argv.(2)|])
    | _         -> usage ()
end

