(* $Id: rpmtest.ml,v 1.2 2005/10/31 20:36:24 martin Exp $
 *
 * rpmtest - example for accessing some header information in an rpm file
 *
 * Copyright (C) 2005  Martin Biely
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)

let rpmerror code string = 
  Printf.fprintf stderr "TEST-ERROR: %d -> %s\n" code string
;;


let open_or_fail fname = 
  match Rpm.openfile fname "r" with
    | Some f -> f
    | _ -> failwith ("open_or_fail")
;;

let _ = Rpm.set_error_callback rpmerror in
let fd = open_or_fail Sys.argv.(1)  in
Printf.printf "file opened!\n";flush stdout;
let _ = Rpm.lead_read fd in
begin
  match Rpm.header_read fd Rpm.HEADER_MAGIC_YES with
    | Some(hdr) -> (
	Printf.printf "read lead\n"; flush stdout;
	( match Rpm.header_get_entry hdr Rpmtag.NAME with
	  | Some(_,Rpm.String(name)) ->  Printf.printf "got name: %s\n" name
	  | None -> Printf.printf "didn't get it\n"
	  | _ -> Printf.printf "not a string\n");
	let iter = Rpm.header_init_iterator hdr in
	();
	
	let rec loop iter = 
	  let x = Rpm.header_next_iterator iter in
	  match x with 
	    | None -> ()
	    | Some((Rpmtag.NAME|Rpmtag.COOKIE),Rpm.String(y)) -> 
		Printf.printf "found name/cookie: %s \n" y;
		loop iter
	    | _ -> loop iter
	in 
	loop iter;
      )
    | _ -> 
	Printf.printf "reading header failed!\n";flush stdout;
end;

let _ = Rpm.closefile fd in
  
Printf.printf "done\n"
